@@ -2,9 +2,11 @@ mod gui;
 mod map;
 mod math;
 mod render;
+mod error;
 
 pub use gui::*;
 pub use map::tiled::*;
 pub use map::*;
 pub use math::*;
 pub use render::*;
+pub use error::*;
